.. Tenso documentation master file

Tenso Documentation
===================

**Tenso** is a high-performance, zero-copy tensor protocol for Python.

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :caption: Contents
   :hidden:

   architecture
   contributing_rust
   reference/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`